@@ -1,8 +1,10 @@
 """Test for asyncprawcore.requestor.Requestor class."""
-import asyncprawcore
-import asynctest
 import asyncio
-from mock import patch, Mock
+
+import asynctest
+from mock import Mock, patch
+
+import asyncprawcore
 from asyncprawcore import RequestException
 
 
@@ -14,9 +16,11 @@ class RequestorTest(asynctest.TestCase):
                     await self.requestor.close()
 
     async def test_initialize(self):
-        self.requestor = asyncprawcore.Requestor("asyncprawcore:test (by /u/bboe)")
+        self.requestor = asyncprawcore.Requestor(
+            "asyncprawcore:test (by /u/Lil_SpazJoekp)"
+        )
         self.assertEqual(
-            f"asyncprawcore:test (by /u/bboe) asyncprawcore/{asyncprawcore.__version__}",
+            f"asyncprawcore:test (by /u/Lil_SpazJoekp) asyncprawcore/{asyncprawcore.__version__}",
             self.requestor._http._default_headers["User-Agent"],
         )
 
@@ -30,7 +34,9 @@ class RequestorTest(asynctest.TestCase):
         exception = Exception("asyncprawcore wrap_request_exceptions")
         session_instance = mock_session.return_value
         session_instance.request.side_effect = exception
-        self.requestor = asyncprawcore.Requestor("asyncprawcore:test (by /u/bboe)")
+        self.requestor = asyncprawcore.Requestor(
+            "asyncprawcore:test (by /u/Lil_SpazJoekp)"
+        )
         with self.assertRaises(asyncprawcore.RequestException) as context_manager:
             await self.requestor.request("get", "http://a.b", data="bar")
         self.assertIsInstance(context_manager.exception, RequestException)
@@ -51,11 +57,11 @@ class RequestorTest(asynctest.TestCase):
         session = Mock(**attrs)
 
         self.requestor = asyncprawcore.Requestor(
-            "asyncprawcore:test (by /u/bboe)", session=session
+            "asyncprawcore:test (by /u/Lil_SpazJoekp)", session=session
         )
 
         self.assertEqual(
-            f"asyncprawcore:test (by /u/bboe) asyncprawcore/{asyncprawcore.__version__}",
+            f"asyncprawcore:test (by /u/Lil_SpazJoekp) asyncprawcore/{asyncprawcore.__version__}",
             self.requestor._http._default_headers["User-Agent"],
         )
         self.assertEqual(
