@@ -111,6 +111,15 @@ class SessionTest(asynctest.TestCase):
         authorizer = asyncprawcore.ImplicitAuthorizer(authenticator, None, 0, "")
         asyncprawcore.Session(authorizer)
 
+    async def test_request__accepted(self):
+        with VCR.use_cassette("Session_request__accepted"):
+            session = asyncprawcore.Session(await script_authorizer())
+            with LogCapture(level=logging.DEBUG) as log_capture:
+                await session.request("POST", "api/read_all_messages")
+            log_capture.check_present(
+                ("asyncprawcore", "DEBUG", "Response: 202 (2 bytes)")
+            )
+
     @patch("aiohttp.ClientSession")
     async def test_request__connection_error_retry(self, mock_session):
         session_instance = mock_session.return_value
@@ -363,6 +372,13 @@ class SessionTest(asynctest.TestCase):
                 await session.request("GET", "/r/random")
             self.assertTrue(context_manager.exception.path.startswith("/r/"))
 
+    async def test_request__redirect_301(self):
+        with VCR.use_cassette("Session_request__redirect_301"):
+            session = asyncprawcore.Session(await readonly_authorizer())
+            with self.assertRaises(asyncprawcore.Redirect) as context_manager:
+                await session.request("GET", "t/bird")
+            self.assertTrue(context_manager.exception.path == "/r/t:bird/")
+
     async def test_request__service_unavailable(self):
         with VCR.use_cassette("Session_request__service_unavailable"):
             self.session = asyncprawcore.Session(await readonly_authorizer())
